# Service components in `ngAnimate`

Name | Description
--- | ---
$animateCss | The `$animateCss` service is a useful utility to trigger customized CSS-based transitions/keyframes from a JavaScript-based animation or directly from a directive. The purpose of `$animateCss` is NOT to side-step how `$animate` and ngAnimate work, but the goal is to allow pre-existing animations or directives to create more complex animations that can be purely driven using CSS code.
$animate | The ngAnimate `$animate` service documentation is the same for the core `$animate` service.